@@ -6,13 +6,14 @@ import pathlib
 import shutil
 import sys
 
+from qBitrr.bundled_data import license_text, patched_version
 from qBitrr.gen_config import MyConfig
 
 APPDATA_FOLDER = pathlib.Path().home().joinpath(".config", "qBitManager")
 APPDATA_FOLDER.mkdir(parents=True, exist_ok=True)
 
 
-def process_flags() -> argparse.Namespace:
+def process_flags() -> argparse.Namespace | bool:
     parser = argparse.ArgumentParser(description="An interface to interact with qBit and *arrs.")
     parser.add_argument(
         "--gen-config",
@@ -21,12 +22,34 @@ def process_flags() -> argparse.Namespace:
         help="Generate a config file in the current working directory.",
         action="store_true",
     )
+    parser.add_argument(
+        "-v", "--version", action="version", version=f"qBitrr version: {patched_version}"
+    )
+
+    parser.add_argument(
+        "-l", "--license", dest="license", action="store_const", const=license_text
+    )
+    parser.add_argument(
+        "-s",
+        "--source",
+        action="store_const",
+        dest="source",
+        const="Source code can be found on: https://github.com/Drapersniper/Qbitrr",
+    )
+
     args = parser.parse_args()
 
     if args.gen_config:
         from qBitrr.gen_config import _write_config_file
 
         _write_config_file()
+        return True
+    elif args.license:
+        print(args.license)
+        return True
+    elif args.source:
+        print(args.source)
+        return True
     return args
 
 
